void init_atom_builder_config(void);
void init_atom_builder_interface(void);
void init_atom_builder_vlan(void);
void init_atom_builder_ports_list(void);
void init_atom_builder_med_power(void);
void init_atom_builder_pis_list(void);
void init_atom_builder_mgmts_list(void);
void init_atom_builder_med_caelements_list(void);
void init_atom_builder_med_location(void);
void init_atom_builder_interfaces_list(void);
void init_atom_builder_med_caelement(void);
void init_atom_builder_med_locations_list(void);
void init_atom_builder_ppvid(void);
void init_atom_builder_med_policy(void);
void init_atom_builder_pi(void);
void init_atom_builder_ppvids_list(void);
void init_atom_builder_port(void);
void init_atom_builder_vlans_list(void);
void init_atom_builder_dot3_power(void);
void init_atom_builder_mgmt(void);
void init_atom_builder_chassis(void);
void init_atom_builder_med_policies_list(void);
void init_atom_builder(void);
void init_atom_builder(void) {
 static int init = 0; if (init) return; init++;
 init_atom_builder_config();
 init_atom_builder_interface();
 init_atom_builder_vlan();
 init_atom_builder_ports_list();
 init_atom_builder_med_power();
 init_atom_builder_pis_list();
 init_atom_builder_mgmts_list();
 init_atom_builder_med_caelements_list();
 init_atom_builder_med_location();
 init_atom_builder_interfaces_list();
 init_atom_builder_med_caelement();
 init_atom_builder_med_locations_list();
 init_atom_builder_ppvid();
 init_atom_builder_med_policy();
 init_atom_builder_pi();
 init_atom_builder_ppvids_list();
 init_atom_builder_port();
 init_atom_builder_vlans_list();
 init_atom_builder_dot3_power();
 init_atom_builder_mgmt();
 init_atom_builder_chassis();
 init_atom_builder_med_policies_list();
}
void init_atom_map_lldpd_protocol_map(void);
void init_atom_map_port_med_policy_map(void);
void init_atom_map_civic_address_type_map(void);
void init_atom_map_port_status_map(void);
void init_atom_map_port_med_pow_priority_map(void);
void init_atom_map_port_med_geoid_map(void);
void init_atom_map_port_dot3_power_pairs_map(void);
void init_atom_map_lldp_agent_map(void);
void init_atom_map_port_dot3_power_priority_map(void);
void init_atom_map_bond_slave_src_mac_map(void);
void init_atom_map_port_med_policy_prio_map(void);
void init_atom_map_lldp_portid_map(void);
void init_atom_map_port_dot3_power_class_map(void);
void init_atom_map(void);
void init_atom_map(void) {
 static int init = 0; if (init) return; init++;
 init_atom_map_lldpd_protocol_map();
 init_atom_map_port_med_policy_map();
 init_atom_map_civic_address_type_map();
 init_atom_map_port_status_map();
 init_atom_map_port_med_pow_priority_map();
 init_atom_map_port_med_geoid_map();
 init_atom_map_port_dot3_power_pairs_map();
 init_atom_map_lldp_agent_map();
 init_atom_map_port_dot3_power_priority_map();
 init_atom_map_bond_slave_src_mac_map();
 init_atom_map_port_med_policy_prio_map();
 init_atom_map_lldp_portid_map();
 init_atom_map_port_dot3_power_class_map();
}
